==> todomod-1.8.zip: todomod/include/task_form.php <==
<?php
// XoopsForm饤֥ɤ߹
include XOOPS_ROOT_PATH."/class/xoopsformloader.php";

// piCal⥸塼򻲹ͤ˺
function get_formtextdateselect( $name , $value )
{
	$jstime = formatTimestamp( time() , 'F j Y, H:i:s' ); // $jstime ˺դȻ֤
	
	$today = formatTimestamp( time(), 's'); // $today ˺դ

	return "
		<input type='text' name='$name' id='$name' size='12' maxlength='12' value='$value' />
		<input type='reset' value='"._MD_TODOMOD_CALENDER."' onclick='
  
  MonthTbl= new Array(31,28,31,30,31,30,31,31,30,31,30,31); // ƷκǸ

  var el = xoopsGetElementById(\"$name\"); // elפϡ\$nameפIDäHTML

  if (el.value == \"\") el.value = \"$today\"; // Ȥͤ˺դ
  
  deadline = el.value.split(\"-\"); // եͤ-פˤäʬ䤷deadlineפȤ
  
  // parseInt()ΰ٤Ƭ;ʬʡ0פ
  if ( !( isNaN(deadline[0]) && isNaN(deadline[1]) && isNaN(deadline[2]) ) ) { // ͤ3ʬ䤵ƤС
  	deadline[0]= deadline[0].substring(deadline[0].search(/[1-9]/)); // 0ơ
  	deadline[1]= deadline[1].substring(deadline[1].search(/[1-9]/));
  	deadline[2]= deadline[2].substring(deadline[2].search(/[1-9]/));
  	deadline_tmp = deadline[0]+\"-\"+deadline[1]+\"-\"+deadline[2]; // Ȥͤƹ
  }

  if (  parseInt(deadline[0]) < 2000 || parseInt(deadline[0]) > 2015 || isNaN(deadline[0]) || // ʬ䤵줿ͤ
        parseInt(deadline[1]) < 1 || parseInt(deadline[1]) > 12      || isNaN(deadline[1]) || // ǤС
        parseInt(deadline[2]) < 1 || parseInt(deadline[2]) > MonthTbl[parseInt(deadline[1])-1] || isNaN(deadline[2]) )
	deadline_tmp = \"$today\"; // Ȥͤ˺դ
  
  // ä硢0פդä
  deadline = deadline_tmp.split(\"-\");
  if ( deadline[1].length < 2  ) { deadline[1]=\"0\"+deadline[1];}
  if ( deadline[2].length < 2  ) { deadline[2]=\"0\"+deadline[2];}
  el.value = deadline[0]+\"-\"+deadline[1]+\"-\"+deadline[2];

  if (calendar != null) {
    calendar.hide();
    calendar.parseDate(el.value);
  } else {
    var cal = new Calendar(false, new Date(\"$jstime\"), selected, closeHandler);
    calendar = cal;
    cal.setRange(2000, 2015);
    calendar.create();
    calendar.parseDate(el.value);
  }
  calendar.sel = el;
  calendar.showAtElement(el);
  Calendar.addEvent(document, \"mousedown\", checkCalendar);
  return false;
		' />
	" ;

}

//οƥեɽ
if ( $mode == 'trashbox')
$task_form = new XoopsThemeForm(_MD_TODOMOD_NEWTASK, "todomod_iform", 'task_post.php?mode=trashbox');
else $task_form = new XoopsThemeForm(_MD_TODOMOD_NEWTASK, "todomod_iform", 'task_post.php');

//'ȥ'
$task_form->addElement(new XoopsFormText(_TITLE, 'task_title', $xoopsModuleConfig['title_width'], 255, isset($task_title) ? $task_title : '' ), false);

//''
$deadline_tray = new XoopsFormElementTray(_MD_TODOMOD_DEADLINE ,'');
$deadline_tray->addElement(new XoopsFormLabel(get_formtextdateselect( 'task_deadline' , isset($task_deadline) ? $task_deadline : '' )) );
$deadline_tray->addElement(new XoopsFormButton( '' , 'task_deadline' , _MD_TODOMOD_CLEAR , 'reset' ));
$task_form->addElement($deadline_tray);

//'ͥ'
$task_select_priority=new XoopsFormSelect( _MD_TODOMOD_PRIORITY ,'task_priority',$task_priority);
$task_select_priority->addOption('0', _MD_TODOMOD_PRIORITY_0);
$task_select_priority->addOption('1', _MD_TODOMOD_PRIORITY_1);
$task_select_priority->addOption('2', _MD_TODOMOD_PRIORITY_2);
$task_select_priority->addOption('3', _MD_TODOMOD_PRIORITY_3);
$task_select_priority->addOption('4', _MD_TODOMOD_PRIORITY_4);
$task_form->addElement($task_select_priority);

//''
$task_select_status=new XoopsFormSelect( _MD_TODOMOD_STATUS ,'task_status', isset($task_status) ? $task_status : 0 );
$task_select_status->addOption('0', _MD_TODOMOD_STATUS_0);
$task_select_status->addOption('1', _MD_TODOMOD_STATUS_1);
$task_select_status->addOption('2', _MD_TODOMOD_STATUS_2);
$task_select_status->addOption('3', _MD_TODOMOD_STATUS_3);
$task_select_status->addOption('4', _MD_TODOMOD_STATUS_4);
$task_form->addElement($task_select_status);

//'ܺ'
$task_form->addElement(new XoopsFormTextArea(_MD_TODOMOD_DETAIL, 'task_detail', isset($task_detail) ? $task_detail : '' , $xoopsModuleConfig['detail_length'], $xoopsModuleConfig['detail_width']), false);

//''''ܥɽ
$button_tray = new XoopsFormElementTray('' ,'');
$button_submit = new XoopsFormButton('', 'submitpost', _SUBMIT, 'submit');
$button_submit->setExtra('onSubmit="return FormCheck()"');
$button_tray->addElement($button_submit);
$button_cancel= new XoopsFormButton('', 'submitpost', _BACK, 'button');
$button_cancel->setExtra('onclick="javascript:history.back(-1)"');
$button_tray->addElement($button_cancel);
$task_form->addElement($button_tray);

//task_id򱣤Ƥ
$task_form->addElement(new XoopsFormHidden('task_id', $task_id));

//ݥåץåץ顼ץå򱣤Ƥ
$task_form->addElement(new XoopsFormHidden('alert_message_0', _MD_TODOMOD_ALERT_0 ));
$task_form->addElement(new XoopsFormHidden('alert_message_1', _MD_TODOMOD_ALERT_1 ));
?>

==> todomod-2.2.zip: todomod/include/task_form.php <==
<?php
// XoopsForm饤֥ɤ߹
include XOOPS_ROOT_PATH."/class/xoopsformloader.php";

// piCal⥸塼򻲹ͤ˺
function get_formtextdateselect( $name , $value )
{
	$jstime = formatTimestamp( time() , 'F j Y, H:i:s' ); // $jstime ˺դȻ֤
	
	$today = formatTimestamp( time(), 's'); // $today ˺դ

	return "
		<input type='text' name='$name' id='$name' size='12' maxlength='12' value='$value' />
		<input type='reset' value='"._MD_TODOMOD_CALENDER."' onclick='
  
  MonthTbl= new Array(31,28,31,30,31,30,31,31,30,31,30,31); // ƷκǸ

  var el = xoopsGetElementById(\"$name\"); // elפϡ\$nameפIDäHTML

  if (el.value == \"\") el.value = \"$today\"; // Ȥͤ˺դ
  
  deadline = el.value.split(\"-\"); // եͤ-פˤäʬ䤷deadlineפȤ
  
  // parseInt()ΰ٤Ƭ;ʬʡ0פ
  if ( !( isNaN(deadline[0]) && isNaN(deadline[1]) && isNaN(deadline[2]) ) ) { // ͤ3ʬ䤵ƤС
  	deadline[0]= deadline[0].substring(deadline[0].search(/[1-9]/)); // 0ơ
  	deadline[1]= deadline[1].substring(deadline[1].search(/[1-9]/));
  	deadline[2]= deadline[2].substring(deadline[2].search(/[1-9]/));
  	deadline_tmp = deadline[0]+\"-\"+deadline[1]+\"-\"+deadline[2]; // Ȥͤƹ
  }

  if (  parseInt(deadline[0]) < 2000 || parseInt(deadline[0]) > 2015 || isNaN(deadline[0]) || // ʬ䤵줿ͤ
        parseInt(deadline[1]) < 1 || parseInt(deadline[1]) > 12      || isNaN(deadline[1]) || // ǤС
        parseInt(deadline[2]) < 1 || parseInt(deadline[2]) > MonthTbl[parseInt(deadline[1])-1] || isNaN(deadline[2]) )
	deadline_tmp = \"$today\"; // Ȥͤ˺դ
  
  // ä硢0פդä
  deadline = deadline_tmp.split(\"-\");
  if ( deadline[1].length < 2  ) { deadline[1]=\"0\"+deadline[1];}
  if ( deadline[2].length < 2  ) { deadline[2]=\"0\"+deadline[2];}
  el.value = deadline[0]+\"-\"+deadline[1]+\"-\"+deadline[2];

  if (calendar != null) {
    calendar.hide();
    calendar.parseDate(el.value);
  } else {
    var cal = new Calendar(false, new Date(\"$jstime\"), selected, closeHandler);
    calendar = cal;
    cal.setRange(2000, 2015);
    calendar.create();
    calendar.parseDate(el.value);
  }
  calendar.sel = el;
  calendar.showAtElement(el);
  Calendar.addEvent(document, \"mousedown\", checkCalendar);
  return false;
		' />
	" ;

}

//οƥեɽ
if ( $mode == 'trashbox')
$task_form = new XoopsThemeForm(_MD_TODOMOD_NEWTASK_TRASHBOX, "todomod_iform", 'task_post.php?mode=trashbox');
else $task_form = new XoopsThemeForm(_MD_TODOMOD_NEWTASK, "todomod_iform", 'task_post.php');

//'ȥ'
$task_form->addElement(new XoopsFormText(_TITLE, 'task_title', $xoopsModuleConfig['title_width'], 255, isset($task_title) ? $task_title : '' ), false);

//''
$deadline_tray = new XoopsFormElementTray(_MD_TODOMOD_DEADLINE ,'');
$deadline_tray->addElement(new XoopsFormLabel(get_formtextdateselect( 'task_deadline' , isset($task_deadline) ? $task_deadline : '' )) );
$deadline_tray->addElement(new XoopsFormButton( '' , 'task_deadline' , _MD_TODOMOD_CLEAR , 'reset' ));
$task_form->addElement($deadline_tray);

//'ͥ'
$task_select_priority=new XoopsFormSelect( _MD_TODOMOD_PRIORITY ,'task_priority',$task_priority);
$task_select_priority->addOption('0', _MD_TODOMOD_PRIORITY_0);
$task_select_priority->addOption('1', _MD_TODOMOD_PRIORITY_1);
$task_select_priority->addOption('2', _MD_TODOMOD_PRIORITY_2);
$task_select_priority->addOption('3', _MD_TODOMOD_PRIORITY_3);
$task_select_priority->addOption('4', _MD_TODOMOD_PRIORITY_4);
$task_form->addElement($task_select_priority);

//''
$task_select_status=new XoopsFormSelect( _MD_TODOMOD_STATUS ,'task_status', isset($task_status) ? $task_status : 0 );
$task_select_status->addOption('0', _MD_TODOMOD_STATUS_0);
$task_select_status->addOption('1', _MD_TODOMOD_STATUS_1);
$task_select_status->addOption('2', _MD_TODOMOD_STATUS_2);
$task_select_status->addOption('3', _MD_TODOMOD_STATUS_3);
$task_select_status->addOption('4', _MD_TODOMOD_STATUS_4);
$task_form->addElement($task_select_status);

//'ܺ'
$task_form->addElement(new XoopsFormTextArea(_MD_TODOMOD_DETAIL, 'task_detail', isset($task_detail) ? $task_detail : '' , $xoopsModuleConfig['detail_length'], $xoopsModuleConfig['detail_width']), false);

//''''ܥɽ
$button_tray = new XoopsFormElementTray('' ,'');
$button_submit = new XoopsFormButton('', 'submitpost', _SUBMIT, 'submit');
$button_submit->setExtra('onSubmit="return FormCheck()"');
$button_tray->addElement($button_submit);
$button_cancel= new XoopsFormButton('', 'submitpost', _BACK, 'button');
$button_cancel->setExtra('onclick="javascript:history.back(-1)"');
$button_tray->addElement($button_cancel);
$task_form->addElement($button_tray);

//task_id򱣤Ƥ
$task_form->addElement(new XoopsFormHidden('task_id', $task_id));

//ݥåץåץ顼ץå򱣤Ƥ
$task_form->addElement(new XoopsFormHidden('alert_message_0', _MD_TODOMOD_ALERT_0 ));
$task_form->addElement(new XoopsFormHidden('alert_message_1', _MD_TODOMOD_ALERT_1 ));
?>
